@@ -950,3 +950,37 @@
 #define GLIB_AVAILABLE_ENUMERATOR_IN_2_78
 #define GLIB_AVAILABLE_TYPE_IN_2_78
 #endif
+
+#if GLIB_VERSION_MIN_REQUIRED >= GLIB_VERSION_2_80
+#define GLIB_DEPRECATED_IN_2_80 GLIB_DEPRECATED
+#define GLIB_DEPRECATED_IN_2_80_FOR(f) GLIB_DEPRECATED_FOR (f)
+#define GLIB_DEPRECATED_MACRO_IN_2_80 GLIB_DEPRECATED_MACRO
+#define GLIB_DEPRECATED_MACRO_IN_2_80_FOR(f) GLIB_DEPRECATED_MACRO_FOR (f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_80 GLIB_DEPRECATED_ENUMERATOR
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_80_FOR(f) GLIB_DEPRECATED_ENUMERATOR_FOR (f)
+#define GLIB_DEPRECATED_TYPE_IN_2_80 GLIB_DEPRECATED_TYPE
+#define GLIB_DEPRECATED_TYPE_IN_2_80_FOR(f) GLIB_DEPRECATED_TYPE_FOR (f)
+#else
+#define GLIB_DEPRECATED_IN_2_80 _GLIB_EXTERN
+#define GLIB_DEPRECATED_IN_2_80_FOR(f) _GLIB_EXTERN
+#define GLIB_DEPRECATED_MACRO_IN_2_80
+#define GLIB_DEPRECATED_MACRO_IN_2_80_FOR(f)
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_80
+#define GLIB_DEPRECATED_ENUMERATOR_IN_2_80_FOR(f)
+#define GLIB_DEPRECATED_TYPE_IN_2_80
+#define GLIB_DEPRECATED_TYPE_IN_2_80_FOR(f)
+#endif
+
+#if GLIB_VERSION_MAX_ALLOWED < GLIB_VERSION_2_80
+#define GLIB_AVAILABLE_IN_2_80 GLIB_UNAVAILABLE (2, 80)
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_80 GLIB_UNAVAILABLE_STATIC_INLINE (2, 80)
+#define GLIB_AVAILABLE_MACRO_IN_2_80 GLIB_UNAVAILABLE_MACRO (2, 80)
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_80 GLIB_UNAVAILABLE_ENUMERATOR (2, 80)
+#define GLIB_AVAILABLE_TYPE_IN_2_80 GLIB_UNAVAILABLE_TYPE (2, 80)
+#else
+#define GLIB_AVAILABLE_IN_2_80 _GLIB_EXTERN
+#define GLIB_AVAILABLE_STATIC_INLINE_IN_2_80
+#define GLIB_AVAILABLE_MACRO_IN_2_80
+#define GLIB_AVAILABLE_ENUMERATOR_IN_2_80
+#define GLIB_AVAILABLE_TYPE_IN_2_80
+#endif
